@@ -198,6 +198,7 @@ class PostProcessors:
                 ZRangeReply: cls.multibulk_as_zrangereply,
 
                 StatusReply: None,
+                (StatusReply, NoneType): None,
                 int: None,
                 (int, NoneType): None,
                 ConfigPairReply: cls.multibulk_as_configpair,
@@ -1036,7 +1037,9 @@ class RedisProtocol(asyncio.Protocol, metaclass=_RedisProtocolMeta):
     # Strings
 
     @_query_command
-    def set(self, key:NativeType, value:NativeType) -> StatusReply:
+    def set(self, key:NativeType, value:NativeType,
+            expire:(int, NoneType)=None, pexpire:(int, NoneType)=None,
+            only_if_not_exists:bool=False, only_if_exists:bool=False) -> (StatusReply, NoneType):
         """
         Set the string value of a key
 
@@ -1045,8 +1048,37 @@ class RedisProtocol(asyncio.Protocol, metaclass=_RedisProtocolMeta):
             yield from protocol.set('key', 'value')
             result = yield from protocol.get('key')
             assert result == 'value'
+
+        To set a value and its expiration, only if key not exists, do:
+
+        ::
+
+            yield from protocol.set('key', 'value', expire=1, only_if_not_exists=True)
+
+        This will send: ``SET key value EX 1 NX`` at the network.
+        To set value and its expiration in milliseconds, but only if key already exists:
+
+        ::
+
+            yield from protocol.set('key', 'value', pexpire=1000, only_if_exists=True)
         """
-        return self._query(b'set', self.encode_from_native(key), self.encode_from_native(value))
+        params = [
+            b'set',
+            self.encode_from_native(key),
+            self.encode_from_native(value)
+        ]
+        if expire is not None:
+            params.extend((b'ex', self._encode_int(expire)))
+        if pexpire is not None:
+            params.extend((b'px', self._encode_int(pexpire)))
+        if only_if_not_exists and only_if_exists:
+            raise ValueError("only_if_not_exists and only_if_exists cannot be true simultaniously")
+        if only_if_not_exists:
+            params.append(b'nx')
+        if only_if_exists:
+            params.append(b'xx')
+
+        return self._query(*params)
 
     @_query_command
     def setex(self, key:NativeType, seconds:int, value:NativeType) -> StatusReply:
